Release Notes
=============

Version 0.0.4
-------------

Release 2017-08-25

* Adds Web API dependency provider
* Adds multi-bot support for RTM extension and Web API dependency provider


Version 0.0.3
-------------

Released 2017-07-27

* Adds replying by returning from handle_message entrypoint


Version 0.0.2
-------------

Released 2017-02-11

* Initial release
* Adds RTM extension
